from argparse import ArgumentParser
from pymacgen import MACGenerator
from loguru import logger as log


def main():
    ap = ArgumentParser()
    ap.add_argument("-o", "--oui", default="/tmp/oui.txt", help="path to oui file; will be downloaded if not found")
    ap.add_argument("-d", "--debug", action="store_true", help="enable debugging")
    ap.add_argument("-org", "--organization", help="search by organization name; case insensitive")
    ap.add_argument("-mp", "--mac-prefix", help="search by mac prefix; 00-00-00 or 00:00:00 or 000000")
    ap.add_argument("-cn", "--country-name", help="search by country name; case insensitive")
    ap.add_argument("-cc", "--country-code", help="search by country code")
    ap.add_argument("-g", "--generate", help="generate a random mac address or by found prefix")
    a = ap.parse_args()
    mg = MACGenerator(a.oui, a.debug)

    i = None
    if a.organization_name is not None:
        i = mg.by_organization(a.organization)
    elif a.mac_prefix is not None:
        i = mg.by_prefix(a.mac_prefix)
    elif a.country_name is not None:
        i = mg.by_country(a.country_name)
    elif a.country_code is not None:
        i = mg.by_

    if i is None:
        log.error("could not find mac info")
        exit()

    if a.generate:
        pass  # todo


if __name__ == '__main__':
    main()



from pyoui import OUI, OuiEntry
from string import hexdigits
from random import choice


class MACGenerator(object):
    oui = None
    debug = False

    def __init__(self, oui_file="/tmp/oui.txt", debug=False):
        self.oui = OUI(oui_file, debug).parse()
        self.debug = debug

    @staticmethod
    def _generate_last_six():
        r = ""
        for i in range(6):
            r += choice(hexdigits)
            if (i % 2) == 1:
                r += ":"
        r = r[0:-1]
        return r.upper()

    @classmethod
    def _generate_from_prefix(cls, prefix: str):
        if not prefix.endswith(":"):
            prefix += ":"
        return prefix + cls._generate_last_six()

    def _generate_from_entry(self, e: OuiEntry):
        return self._generate_from_prefix(e.prefix)

    def by_organization(self, name):  # todo by best matching
        return self._generate_from_entry(list(self.oui.by_organization(name))[0])

    @staticmethod
    def by_prefix(prefix):
        return MACGenerator._generate_from_prefix(prefix)

    def by_country_name(self, name):
        return self._generate_from_entry(list(self.oui.by_country_code(name))[0])

    def by_country_code(self, code):
        return self._generate_from_prefix(list(self.oui.by_country_code(code))[0])

    @staticmethod
    def by_mac(mac: str):
        return MACGenerator._generate_from_prefix(mac.replace(":", "")[0:6])



from setuptools import setup, find_packages

setup(
    long_description=open("README.rst", "r").read(),
    name="pymacgen",
    version="0.2",
    description="generate mac addresses",
    author="Pascal Eberlein",
    author_email="pascal@eberlein.io",
    url="https://github.com/smthnspcl/pymacgen",
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7',
    ],
    keywords="mac generator",
    packages=find_packages(),
    include_package_data=True,
    entry_points={'console_scripts': ['pymacgen = pymacgen.__main__:main']},
    install_requires=open("requirements.txt").readlines()
)
